--[[ Gear Aug Checker by MrInfernal v1.6

/augcheck <empty|filled|all> *<augtype#>*

ex: /augcheck empty
    /augcheck empty 9
    /augcheck all

Look through worn gear to return aug slots that are empty or tell you if they are empty/filled
Can sort by a type number

Close program with exit, close, or stop
ex: /augcheck stop
]]

local mq = require('mq')

local run = true

local gearSlotVis = {
    'head', -- 1
    'arms',
    'leftwrist',
    'rightwrist',
    'hands',  -- 5
    'chest',
    'legs',
    'feet',  -- 8
}

local gearSlotNonVis = {
    'leftear', -- 1
    'rightear',
    'face',
    'neck',
    'shoulder',  -- 5
    'back',
    'leftfinger',
    'rightfinger',
    'waist',
    'charm',  -- 10
}

local gearSlotWep = {
    'mainhand',
    'offhand',
    'ranged'
}

local function ShowHelp(useargs)
    print('Aug Checker by \arMrInfernal ')
    if useargs == 0 then
        print('\nUsage: \ao/augcheck \ax<\arempty\ax|\agfilled\ax|\agall\ax> \at<augtype#>') 
    else
        print('\nUsage: \ao/lua run augcheck \ax<\arempty\ax|\agfilled\ax|\agall\ax> \at<augtype#>') 
    end
    print('\arEmpty\ax, \agFilled\ax, or \agAll \ax-- Only \arEmpty \axor \agFilled \axslots or \arEmpty\ax/\agFilled')
    print('\atAugType#\ax: Type number \ax-- \ay(Optional) \axOnly search this slot type\n')
    --print('\nRun \ao/augcheck <augslot> \axwith an augment on cursor -- Check for slots that fit')
    if useargs == 0 then print('\n \ao/augcheck help \ax-- Show this help message again\n') end
end

local function runCheck(target, arg2)
    local typenum = tonumber(arg2)
    
    if target == 'exit' or target == 'stop' or target == 'close' then
        mq.unbind('/augcheck')
        run = false
    elseif target == 'help' then
        ShowHelp()
    -- Check all slots for type#
    elseif target == 'all' and typenum ~= nil and typenum > 0 and typenum <= 22 then
        printf('Displaying status of all type %d slots\n', typenum)
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        --print('\n')
    elseif target == 'filled' and typenum ~= nil and typenum > 0 and typenum <= 22 then
        printf('Displaying filled type %d slots\n', typenum)
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '

            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        --print('\n')
    -- Empty type# slots
    elseif target == 'empty' and typenum ~= nil and typenum > 0 and typenum <= 22 then
        printf('Displaying empty type %d slots\n', typenum)
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                else
                    print('No Empty Type %d slots found', typenum)
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                else
                    print('No Empty Type %d slots found', typenum)
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '

            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                else
                    print('No Empty Type %d slots found', typenum)
                end
            end
        end
        --print('\n')
    -- Show Empty/Filled
    elseif target == 'all' then
    print('Displaying Fill status for all aug slots\n')
    for _, item in ipairs(gearSlotVis) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear.ID() then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                        table.insert(gearSlots, aug)
                    elseif not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    for _, item in ipairs(gearSlotNonVis) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear.ID() then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                        table.insert(gearSlots, aug)
                    elseif not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    for _, item in ipairs(gearSlotWep) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear.ID() then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                        table.insert(gearSlots, aug)
                    elseif not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    --print('\n')
    -- Show Filled
elseif target == 'filled' then
    print('Displaying Filled status for all aug slots\n')
    for _, item in ipairs(gearSlotVis) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear.ID() then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    for _, item in ipairs(gearSlotNonVis) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear.ID() then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    for _, item in ipairs(gearSlotWep) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear.ID() then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    --print('\n')
    else-- Default. Only show Empty
        print('Only displaying Empty aug slots\n')
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                else
                    print('No Empty slots found')
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                else
                    print('No Empty slots found')
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                else
                    print('No Empty slots found')
                end
            end
        end
        --print('\n')
    end
end

local args = {...}
ShowHelp(#args)
if #args == 1 then
    
    runCheck(args[1])
elseif #args == 2  then
    runCheck(args[1], args[2])
else
    mq.bind('/augcheck', runCheck)
    while run do
        mq.delay(1000)
    end
end

